// Theme Toggle Functionality
document.addEventListener('DOMContentLoaded', () => {
    const themeToggle = document.getElementById('theme-toggle');
    const prefersDarkScheme = window.matchMedia('(prefers-color-scheme: dark)');
    
    // Check for saved theme preference or use system preference
    const currentTheme = localStorage.getItem('theme');
    if (currentTheme) {
        document.documentElement.setAttribute('data-theme', currentTheme);
        themeToggle.checked = currentTheme === 'dark';
    } else {
        themeToggle.checked = prefersDarkScheme.matches;
        document.documentElement.setAttribute('data-theme', prefersDarkScheme.matches ? 'dark' : 'light');
    }

    // Handle theme toggle changes
    themeToggle.addEventListener('change', function() {
        const theme = this.checked ? 'dark' : 'light';
        document.documentElement.setAttribute('data-theme', theme);
        localStorage.setItem('theme', theme);
    });

    // Listen for system theme changes
    prefersDarkScheme.addEventListener('change', (e) => {
        if (!localStorage.getItem('theme')) {
            const theme = e.matches ? 'dark' : 'light';
            document.documentElement.setAttribute('data-theme', theme);
            themeToggle.checked = e.matches;
        }
    });
});

// Email Management
let emails = JSON.parse(localStorage.getItem('emails') || '[]');

function addEmail() {
    const emailInput = document.getElementById('emailInput');
    const email = emailInput.value.trim();
    
    if (!email) {
        alert('Please enter an email address');
        return;
    }
    
    if (!isValidEmail(email)) {
        alert('Please enter a valid email address');
        return;
    }
    
    if (emails.includes(email)) {
        alert('This email is already in the list');
        return;
    }
    
    emails.push(email);
    localStorage.setItem('emails', JSON.stringify(emails));
    emailInput.value = '';
    displayEmails();
}

function removeEmail(email) {
    emails = emails.filter(e => e !== email);
    localStorage.setItem('emails', JSON.stringify(emails));
    displayEmails();
}

function displayEmails() {
    const tbody = document.getElementById('emailTableBody');
    tbody.innerHTML = '';
    
    emails.forEach(email => {
        const tr = document.createElement('tr');
        tr.innerHTML = `
            <td>${email}</td>
            <td>
                <button onclick="removeEmail('${email}')" style="background-color: #dc3545;">
                    Remove
                </button>
            </td>
        `;
        tbody.appendChild(tr);
    });
}

function isValidEmail(email) {
    const emailRegex = /^[^\s@]+@[^\s@]+\.[^\s@]+$/;
    return emailRegex.test(email);
}

// Show recent emails on page load
document.addEventListener('DOMContentLoaded', () => {
    displayEmails();
    
    // Add email form submission
    document.getElementById('addEmailBtn').addEventListener('click', addEmail);
    document.getElementById('emailInput').addEventListener('keypress', (e) => {
        if (e.key === 'Enter') {
            addEmail();
        }
    });
}); 